@@ -9,7 +9,7 @@ def test_mu_fidelity():
     input_shape, nb_labels, nb_samples = ((32, 32, 3), 10, 20)
     x, y = generate_data(input_shape, nb_labels, nb_samples)
     model = generate_model(input_shape, nb_labels)
-    explainer = lambda x, y : np.random.uniform(0, 1, x.shape[:-1])
+    explanations = np.random.uniform(0, 1, x.shape[:-1])
 
     nb_estimation = 10 # number of samples to test correlation for each samples
 
@@ -19,7 +19,7 @@ def test_mu_fidelity():
                 score = MuFidelity(model, x, y, grid_size=grid_size,
                                    subset_percent=subset_percent,
                                    baseline_mode=baseline_mode,
-                                   nb_samples=nb_estimation)(explainer)
+                                   nb_samples=nb_estimation)(explanations)
                 assert -1.0 < score < 1.0
 
 
@@ -28,16 +28,16 @@ def test_causal_metrics():
     input_shape, nb_labels, nb_samples = ((32, 32, 3), 10, 20)
     x, y = generate_data(input_shape, nb_labels, nb_samples)
     model = generate_model(input_shape, nb_labels)
-    explainer = lambda x, y : np.random.uniform(0, 1, x.shape[:-1])
+    explanations = np.random.uniform(0, 1, x.shape[:-1])
 
     for step in [5, 10]:
         for baseline_mode in [0.0, lambda x: x-0.5]:
             score_insertion = Insertion(model, x, y,
                                         baseline_mode=baseline_mode,
-                                        steps=step)(explainer)
+                                        steps=step)(explanations)
             score_deletion = Deletion(model, x, y,
                                       baseline_mode=baseline_mode,
-                                      steps=step)(explainer)
+                                      steps=step)(explanations)
 
             for score in [score_insertion, score_deletion]:
                 assert 0.0 < score < 1.0
@@ -53,12 +53,12 @@ def test_perfect_correlation():
     input_shape, nb_labels, nb_samples = ((32, 32, 1), nb_classes, 20)
     x, y = generate_data(input_shape, nb_labels, nb_samples)
     model = lambda x: tf.repeat(tf.reduce_sum(x, axis=(1, 2, 3))[:, None], nb_classes, -1)
-    explainer = lambda x, y: x
+    explanations = x
 
     perfect_score = MuFidelity(model, x, y, grid_size=None,
                                subset_percent=0.1,
                                baseline_mode=0.0,
-                               nb_samples=200)(explainer)
+                               nb_samples=200)(explanations)
     assert almost_equal(perfect_score, 1.0)
 
 
@@ -72,12 +72,12 @@ def test_worst_correlation():
     input_shape, nb_labels, nb_samples = ((32, 32, 1), nb_classes, 20)
     x, y = generate_data(input_shape, nb_labels, nb_samples)
     model = lambda x: tf.repeat(tf.reduce_sum(x, axis=(1, 2, 3))[:, None], nb_classes, -1)
-    explainer = lambda x, y: -x
+    explanations = -x
 
     perfect_score = MuFidelity(model, x, y, grid_size=None,
                                subset_percent=0.1,
                                baseline_mode=0.0,
-                               nb_samples=200)(explainer)
+                               nb_samples=200)(explanations)
     assert almost_equal(perfect_score, -1.0)
 
 
@@ -92,9 +92,9 @@ def test_perfect_deletion():
     x, y = generate_data(input_shape, nb_labels, nb_samples)
 
     model = lambda x: 1.0 - tf.reduce_max(tf.cast(x == 0.0, tf.float32), (1, 2))
-    explainer = lambda x, y: x
+    explanations = x
 
-    perfect_score = Deletion(model, x, y, steps=steps)(explainer)
+    perfect_score = Deletion(model, x, y, steps=steps)(explanations)
     assert almost_equal(perfect_score, ((1.0 + 0.0) / 2.0) / steps)
 
 
@@ -109,7 +109,7 @@ def test_perfect_insertion():
     x, y = generate_data(input_shape, nb_labels, nb_samples)
 
     model = lambda x: tf.reduce_max(tf.cast(x != 0.0, tf.float32), (1, 2))
-    explainer = lambda x, y: x
+    explanations = x
 
-    perfect_score = Insertion(model, x, y, steps=steps)(explainer)
+    perfect_score = Insertion(model, x, y, steps=steps)(explanations)
     assert almost_equal(perfect_score, 1.0 - ((0.0 + 1.0) / 2.0) / steps)
