@@ -3,9 +3,11 @@ Module related to Gradient x Input method
 """
 
 import tensorflow as tf
+import numpy as np
 
-from .base import WhiteBoxExplainer
-from ..utils import sanitize_input_output
+from .base import WhiteBoxExplainer, sanitize_input_output
+from ..commons import batch_gradient
+from ..types import Optional, Union
 
 
 class GradientInput(WhiteBoxExplainer):
@@ -27,8 +29,8 @@ class GradientInput(WhiteBoxExplainer):
 
     @sanitize_input_output
     def explain(self,
-                inputs: tf.Tensor,
-                labels: tf.Tensor) -> tf.Tensor:
+                inputs: Union[tf.data.Dataset, tf.Tensor, np.ndarray],
+                targets: Optional[Union[tf.Tensor, np.ndarray]] = None) -> tf.Tensor:
         """
         Compute gradients x inputs for a batch of samples.
 
@@ -36,15 +38,15 @@ class GradientInput(WhiteBoxExplainer):
         ----------
         inputs
             Input samples to be explained.
-        labels
-            One-hot encoded labels, one for each sample.
+        targets
+            One-hot encoded labels or regression target (e.g {+1, -1}), one for each sample.
 
         Returns
         -------
         explanations
             Gradients x Inputs, with the same shape as the inputs.
         """
-        gradients = WhiteBoxExplainer._batch_gradient(self.model, inputs, labels, self.batch_size)
+        gradients = batch_gradient(self.model, inputs, targets, self.batch_size)
         gradients_inputs = tf.multiply(gradients, inputs)
 
         return gradients_inputs
